@@ -1,9 +1,11 @@
 
 
--- UUAGC 0.9.14 (DeclBlocks.ag)
+-- UUAGC 0.9.37.1 (DeclBlocks.ag)
 module DeclBlocks where
+{-# LINE 2 "DeclBlocks.ag" #-}
 
 import Code (Decl,Expr)
+{-# LINE 9 "../src-derived/DeclBlocks.hs" #-}
 -- DeclBlocks --------------------------------------------------
 {-
    alternatives:
@@ -15,12 +17,12 @@ import Code (Decl,Expr)
          child defs           : {[Decl]}
          child result         : {Expr}
 -}
-data DeclBlocks  = DeclBlock ([Decl]) (Decl) (DeclBlocks) 
-                 | DeclTerminator ([Decl]) (Expr) 
+data DeclBlocks  = DeclBlock (([Decl])) (Decl) (DeclBlocks ) 
+                 | DeclTerminator (([Decl])) (Expr) 
 -- DeclBlocksRoot ----------------------------------------------
 {-
    alternatives:
       alternative DeclBlocksRoot:
          child blocks         : DeclBlocks 
 -}
-data DeclBlocksRoot  = DeclBlocksRoot (DeclBlocks) 
\ No newline at end of file
+data DeclBlocksRoot  = DeclBlocksRoot (DeclBlocks ) 
\ No newline at end of file
