@@ -1,10 +1,12 @@
 
 
--- UUAGC 0.9.14 (Expression.ag)
+-- UUAGC 0.9.37.1 (Expression.ag)
 module Expression where
+{-# LINE 2 "Expression.ag" #-}
 
 import UU.Scanner.Position(Pos)
 import HsToken
+{-# LINE 10 "../src-derived/Expression.hs" #-}
 -- Expression --------------------------------------------------
 {-
    alternatives:
@@ -12,4 +14,4 @@ import HsToken
          child pos            : {Pos}
          child tks            : {[HsToken]}
 -}
-data Expression  = Expression (Pos) ([HsToken]) 
\ No newline at end of file
+data Expression  = Expression (Pos) (([HsToken])) 
\ No newline at end of file
