@@ -1,17 +1,19 @@
 
 
--- UUAGC 0.9.14 (Interfaces.ag)
+-- UUAGC 0.9.37.1 (Interfaces.ag)
 module Interfaces where
+{-# LINE 2 "Interfaces.ag" #-}
 
 import CommonTypes
 import SequentialTypes
+{-# LINE 10 "../src-derived/Interfaces.hs" #-}
 -- IRoot -------------------------------------------------------
 {-
    alternatives:
       alternative IRoot:
          child inters         : Interfaces 
 -}
-data IRoot  = IRoot (Interfaces) 
+data IRoot  = IRoot (Interfaces ) 
 -- Interface ---------------------------------------------------
 {-
    alternatives:
@@ -20,7 +22,7 @@ data IRoot  = IRoot (Interfaces)
          child cons           : {[ConstructorIdent]}
          child seg            : Segments 
 -}
-data Interface  = Interface (NontermIdent) ([ConstructorIdent]) (Segments) 
+data Interface  = Interface (NontermIdent) (([ConstructorIdent])) (Segments ) 
 -- Interfaces --------------------------------------------------
 {-
    alternatives:
@@ -29,7 +31,7 @@ data Interface  = Interface (NontermIdent) ([ConstructorIdent]) (Segments)
          child tl             : Interfaces 
       alternative Nil:
 -}
-type Interfaces  = [(Interface)]
+type Interfaces  = [Interface ]
 -- Segment -----------------------------------------------------
 {-
    alternatives:
@@ -37,7 +39,7 @@ type Interfaces  = [(Interface)]
          child inh            : {[Vertex]}
          child syn            : {[Vertex]}
 -}
-data Segment  = Segment ([Vertex]) ([Vertex]) 
+data Segment  = Segment (([Vertex])) (([Vertex])) 
 -- Segments ----------------------------------------------------
 {-
    alternatives:
@@ -46,4 +48,4 @@ data Segment  = Segment ([Vertex]) ([Vertex])
          child tl             : Segments 
       alternative Nil:
 -}
-type Segments  = [(Segment)]
\ No newline at end of file
+type Segments  = [Segment ]
\ No newline at end of file
