@@ -1,7 +1,8 @@
 
 
--- UUAGC 0.9.14 (Visage.ag)
+-- UUAGC 0.9.37.1 (Visage.ag)
 module Visage where
+{-# LINE 6 "Visage.ag" #-}
 
 import UU.Scanner.Position(Pos(..))
 import CommonTypes
@@ -13,21 +14,29 @@ import qualified Data.Map as Map
 import Data.Map(Map)
 import Data.List(intersperse)
 import TokenDef
+{-# LINE 18 "../src-derived/Visage.hs" #-}
 
+{-# LINE 2 "./VisageSyntax.ag" #-}
 
 import CommonTypes
 import UU.Pretty
 import AbstractSyntax
 import VisagePatterns
 import Expression
+{-# LINE 27 "../src-derived/Visage.hs" #-}
 
+{-# LINE 2 "./VisagePatterns.ag" #-}
 
 import UU.Scanner.Position(Pos)
 import CommonTypes
+{-# LINE 33 "../src-derived/Visage.hs" #-}
 
+{-# LINE 2 "./Expression.ag" #-}
 
 import UU.Scanner.Position(Pos)
 import HsToken
+{-# LINE 39 "../src-derived/Visage.hs" #-}
+{-# LINE 19 "Visage.ag" #-}
 
 convert :: String -> String
 convert [] = []
@@ -52,6 +61,7 @@ showMap
   where
     braces s = "{" ++ s ++ "}"
     assign a b = show a ++ ":=" ++ show b
+{-# LINE 65 "../src-derived/Visage.hs" #-}
 -- Expression --------------------------------------------------
 {-
    visit 0:
@@ -75,8 +85,7 @@ wrap_Expression :: T_Expression  ->
                    Inh_Expression  ->
                    Syn_Expression 
 wrap_Expression (T_Expression sem ) (Inh_Expression )  =
-    (let ( _lhsOaterm) =
-             (sem )
+    (let ( _lhsOaterm) = sem 
      in  (Syn_Expression _lhsOaterm ))
 sem_Expression_Expression :: Pos ->
                              ([HsToken]) ->
@@ -85,7 +94,10 @@ sem_Expression_Expression pos_ tks_  =
     (T_Expression (let _lhsOaterm :: ATerm
                        -- "Visage.ag"(line 103, column 17)
                        _lhsOaterm =
-                           AAppl "Expression" [AString (sQ (showAGPos pos_)), AString (sQ (unlines . showTokens . tokensToStrings $ tks_))]
+                           ({-# LINE 103 "Visage.ag" #-}
+                            AAppl "Expression" [AString (sQ (showAGPos pos_)), AString (sQ (unlines . showTokens . tokensToStrings $ tks_))]
+                            {-# LINE 100 "Visage.hs" #-}
+                            )
                    in  ( _lhsOaterm)) )
 -- VisageChild -------------------------------------------------
 {-
@@ -113,8 +125,7 @@ wrap_VisageChild :: T_VisageChild  ->
                     Inh_VisageChild  ->
                     Syn_VisageChild 
 wrap_VisageChild (T_VisageChild sem ) (Inh_VisageChild )  =
-    (let ( _lhsOaterm) =
-             (sem )
+    (let ( _lhsOaterm) = sem 
      in  (Syn_VisageChild _lhsOaterm ))
 sem_VisageChild_VChild :: Identifier ->
                           Type ->
@@ -128,15 +139,21 @@ sem_VisageChild_VChild name_ tp_ inh_ syn_ (T_VisageRules rules_ )  =
                         _rulesIaterms :: ([ATerm])
                         -- "Visage.ag"(line 85, column 18)
                         _lhsOaterm =
-                            AAppl "Child" [AString (sQ (getName name_)), AString (sQ (show tp_)),
-                                           AString (sQ (showMap inh_)),
-                                           AString (sQ (showMap syn_)),
-                                           AAppl "Rules" _rulesIaterms]
+                            ({-# LINE 85 "Visage.ag" #-}
+                             AAppl "Child" [AString (sQ (getName name_)), AString (sQ (show tp_)),
+                                            AString (sQ (showMap inh_)),
+                                            AString (sQ (showMap syn_)),
+                                            AAppl "Rules" _rulesIaterms]
+                             {-# LINE 148 "Visage.hs" #-}
+                             )
                         -- "Visage.ag"(line 89, column 18)
                         _rulesOisLoc =
-                            False
+                            ({-# LINE 89 "Visage.ag" #-}
+                             False
+                             {-# LINE 154 "Visage.hs" #-}
+                             )
                         ( _rulesIaterms) =
-                            (rules_ _rulesOisLoc )
+                            rules_ _rulesOisLoc 
                     in  ( _lhsOaterm)) )
 -- VisageChildren ----------------------------------------------
 {-
@@ -157,13 +174,12 @@ sem_VisageChildren list  =
 -- semantic domain
 newtype T_VisageChildren  = T_VisageChildren (( ([ATerm])))
 data Inh_VisageChildren  = Inh_VisageChildren {}
-data Syn_VisageChildren  = Syn_VisageChildren {aterms_Syn_VisageChildren :: [ATerm]}
+data Syn_VisageChildren  = Syn_VisageChildren {aterms_Syn_VisageChildren :: ([ATerm])}
 wrap_VisageChildren :: T_VisageChildren  ->
                        Inh_VisageChildren  ->
                        Syn_VisageChildren 
 wrap_VisageChildren (T_VisageChildren sem ) (Inh_VisageChildren )  =
-    (let ( _lhsOaterms) =
-             (sem )
+    (let ( _lhsOaterms) = sem 
      in  (Syn_VisageChildren _lhsOaterms ))
 sem_VisageChildren_Cons :: T_VisageChild  ->
                            T_VisageChildren  ->
@@ -174,18 +190,24 @@ sem_VisageChildren_Cons (T_VisageChild hd_ ) (T_VisageChildren tl_ )  =
                            _tlIaterms :: ([ATerm])
                            -- "Visage.ag"(line 80, column 17)
                            _lhsOaterms =
-                               _hdIaterm : _tlIaterms
+                               ({-# LINE 80 "Visage.ag" #-}
+                                _hdIaterm : _tlIaterms
+                                {-# LINE 196 "Visage.hs" #-}
+                                )
                            ( _hdIaterm) =
-                               (hd_ )
+                               hd_ 
                            ( _tlIaterms) =
-                               (tl_ )
+                               tl_ 
                        in  ( _lhsOaterms)) )
 sem_VisageChildren_Nil :: T_VisageChildren 
 sem_VisageChildren_Nil  =
     (T_VisageChildren (let _lhsOaterms :: ([ATerm])
                            -- "Visage.ag"(line 81, column 17)
                            _lhsOaterms =
-                               []
+                               ({-# LINE 81 "Visage.ag" #-}
+                                []
+                                {-# LINE 210 "Visage.hs" #-}
+                                )
                        in  ( _lhsOaterms)) )
 -- VisageGrammar -----------------------------------------------
 {-
@@ -209,8 +231,7 @@ wrap_VisageGrammar :: T_VisageGrammar  ->
                       Inh_VisageGrammar  ->
                       Syn_VisageGrammar 
 wrap_VisageGrammar (T_VisageGrammar sem ) (Inh_VisageGrammar )  =
-    (let ( _lhsOaterm) =
-             (sem )
+    (let ( _lhsOaterm) = sem 
      in  (Syn_VisageGrammar _lhsOaterm ))
 sem_VisageGrammar_VGrammar :: T_VisageNonterminals  ->
                               T_VisageGrammar 
@@ -219,9 +240,12 @@ sem_VisageGrammar_VGrammar (T_VisageNonterminals nonts_ )  =
                           _nontsIaterms :: ([ATerm])
                           -- "Visage.ag"(line 54, column 18)
                           _lhsOaterm =
-                              AAppl "Productions" _nontsIaterms
+                              ({-# LINE 54 "Visage.ag" #-}
+                               AAppl "Productions" _nontsIaterms
+                               {-# LINE 246 "Visage.hs" #-}
+                               )
                           ( _nontsIaterms) =
-                              (nonts_ )
+                              nonts_ 
                       in  ( _lhsOaterm)) )
 -- VisageNonterminal -------------------------------------------
 {-
@@ -248,8 +272,7 @@ wrap_VisageNonterminal :: T_VisageNonterminal  ->
                           Inh_VisageNonterminal  ->
                           Syn_VisageNonterminal 
 wrap_VisageNonterminal (T_VisageNonterminal sem ) (Inh_VisageNonterminal )  =
-    (let ( _lhsOaterm) =
-             (sem )
+    (let ( _lhsOaterm) = sem 
      in  (Syn_VisageNonterminal _lhsOaterm ))
 sem_VisageNonterminal_VNonterminal :: NontermIdent ->
                                       Attributes ->
@@ -261,10 +284,13 @@ sem_VisageNonterminal_VNonterminal nt_ inh_ syn_ (T_VisageProductions alts_ )  =
                               _altsIaterms :: ([ATerm])
                               -- "Visage.ag"(line 63, column 19)
                               _lhsOaterm =
-                                  AAppl "Production" [AString (sQ (getName nt_)), AString (sQ(showMap inh_)),
-                                                     AString (sQ(showMap syn_)), AAppl "Alternatives" _altsIaterms]
+                                  ({-# LINE 63 "Visage.ag" #-}
+                                   AAppl "Production" [AString (sQ (getName nt_)), AString (sQ(showMap inh_)),
+                                                      AString (sQ(showMap syn_)), AAppl "Alternatives" _altsIaterms]
+                                   {-# LINE 291 "Visage.hs" #-}
+                                   )
                               ( _altsIaterms) =
-                                  (alts_ )
+                                  alts_ 
                           in  ( _lhsOaterm)) )
 -- VisageNonterminals ------------------------------------------
 {-
@@ -285,13 +311,12 @@ sem_VisageNonterminals list  =
 -- semantic domain
 newtype T_VisageNonterminals  = T_VisageNonterminals (( ([ATerm])))
 data Inh_VisageNonterminals  = Inh_VisageNonterminals {}
-data Syn_VisageNonterminals  = Syn_VisageNonterminals {aterms_Syn_VisageNonterminals :: [ATerm]}
+data Syn_VisageNonterminals  = Syn_VisageNonterminals {aterms_Syn_VisageNonterminals :: ([ATerm])}
 wrap_VisageNonterminals :: T_VisageNonterminals  ->
                            Inh_VisageNonterminals  ->
                            Syn_VisageNonterminals 
 wrap_VisageNonterminals (T_VisageNonterminals sem ) (Inh_VisageNonterminals )  =
-    (let ( _lhsOaterms) =
-             (sem )
+    (let ( _lhsOaterms) = sem 
      in  (Syn_VisageNonterminals _lhsOaterms ))
 sem_VisageNonterminals_Cons :: T_VisageNonterminal  ->
                                T_VisageNonterminals  ->
@@ -302,18 +327,24 @@ sem_VisageNonterminals_Cons (T_VisageNonterminal hd_ ) (T_VisageNonterminals tl_
                                _tlIaterms :: ([ATerm])
                                -- "Visage.ag"(line 58, column 17)
                                _lhsOaterms =
-                                   _hdIaterm : _tlIaterms
+                                   ({-# LINE 58 "Visage.ag" #-}
+                                    _hdIaterm : _tlIaterms
+                                    {-# LINE 333 "Visage.hs" #-}
+                                    )
                                ( _hdIaterm) =
-                                   (hd_ )
+                                   hd_ 
                                ( _tlIaterms) =
-                                   (tl_ )
+                                   tl_ 
                            in  ( _lhsOaterms)) )
 sem_VisageNonterminals_Nil :: T_VisageNonterminals 
 sem_VisageNonterminals_Nil  =
     (T_VisageNonterminals (let _lhsOaterms :: ([ATerm])
                                -- "Visage.ag"(line 59, column 17)
                                _lhsOaterms =
-                                   []
+                                   ({-# LINE 59 "Visage.ag" #-}
+                                    []
+                                    {-# LINE 347 "Visage.hs" #-}
+                                    )
                            in  ( _lhsOaterms)) )
 -- VisagePattern -----------------------------------------------
 {-
@@ -358,8 +389,7 @@ wrap_VisagePattern :: T_VisagePattern  ->
                       Inh_VisagePattern  ->
                       Syn_VisagePattern 
 wrap_VisagePattern (T_VisagePattern sem ) (Inh_VisagePattern )  =
-    (let ( _lhsOaterm) =
-             (sem )
+    (let ( _lhsOaterm) = sem 
      in  (Syn_VisagePattern _lhsOaterm ))
 sem_VisagePattern_VAlias :: Identifier ->
                             Identifier ->
@@ -370,10 +400,13 @@ sem_VisagePattern_VAlias field_ attr_ (T_VisagePattern pat_ )  =
                           _patIaterm :: ATerm
                           -- "Visage.ag"(line 119, column 18)
                           _lhsOaterm =
-                              AAppl "Pattern" [AAppl "Alias" [AString (sQ (showAGPos (getPos field_))),
-                                                              AString (sQ (getName field_ ++ "." ++ getName attr_)), _patIaterm]]
+                              ({-# LINE 119 "Visage.ag" #-}
+                               AAppl "Pattern" [AAppl "Alias" [AString (sQ (showAGPos (getPos field_))),
+                                                               AString (sQ (getName field_ ++ "." ++ getName attr_)), _patIaterm]]
+                               {-# LINE 407 "Visage.hs" #-}
+                               )
                           ( _patIaterm) =
-                              (pat_ )
+                              pat_ 
                       in  ( _lhsOaterm)) )
 sem_VisagePattern_VConstr :: ConstructorIdent ->
                              T_VisagePatterns  ->
@@ -383,11 +416,14 @@ sem_VisagePattern_VConstr name_ (T_VisagePatterns pats_ )  =
                           _patsIaterms :: ([ATerm])
                           -- "Visage.ag"(line 112, column 18)
                           _lhsOaterm =
-                              AAppl "Pattern" [AAppl "Constr" [AString (sQ (showAGPos (getPos name_))),
-                                               AString (sQ (getName name_)),
-                                               AAppl "Patterns" _patsIaterms]]
+                              ({-# LINE 112 "Visage.ag" #-}
+                               AAppl "Pattern" [AAppl "Constr" [AString (sQ (showAGPos (getPos name_))),
+                                                AString (sQ (getName name_)),
+                                                AAppl "Patterns" _patsIaterms]]
+                               {-# LINE 424 "Visage.hs" #-}
+                               )
                           ( _patsIaterms) =
-                              (pats_ )
+                              pats_ 
                       in  ( _lhsOaterm)) )
 sem_VisagePattern_VProduct :: Pos ->
                               T_VisagePatterns  ->
@@ -397,10 +433,13 @@ sem_VisagePattern_VProduct pos_ (T_VisagePatterns pats_ )  =
                           _patsIaterms :: ([ATerm])
                           -- "Visage.ag"(line 115, column 18)
                           _lhsOaterm =
-                              AAppl "Pattern" [AAppl "Product" [AString (sQ (showAGPos pos_)),
-                                                                AAppl "Patterns" _patsIaterms]]
+                              ({-# LINE 115 "Visage.ag" #-}
+                               AAppl "Pattern" [AAppl "Product" [AString (sQ (showAGPos pos_)),
+                                                                 AAppl "Patterns" _patsIaterms]]
+                               {-# LINE 440 "Visage.hs" #-}
+                               )
                           ( _patsIaterms) =
-                              (pats_ )
+                              pats_ 
                       in  ( _lhsOaterm)) )
 sem_VisagePattern_VUnderscore :: Pos ->
                                  T_VisagePattern 
@@ -408,7 +447,10 @@ sem_VisagePattern_VUnderscore pos_  =
     (T_VisagePattern (let _lhsOaterm :: ATerm
                           -- "Visage.ag"(line 121, column 18)
                           _lhsOaterm =
-                              AAppl "Pattern" [AAppl "Underscore" [AString (sQ (showAGPos pos_))]]
+                              ({-# LINE 121 "Visage.ag" #-}
+                               AAppl "Pattern" [AAppl "Underscore" [AString (sQ (showAGPos pos_))]]
+                               {-# LINE 453 "Visage.hs" #-}
+                               )
                       in  ( _lhsOaterm)) )
 sem_VisagePattern_VVar :: Identifier ->
                           Identifier ->
@@ -417,8 +459,11 @@ sem_VisagePattern_VVar field_ attr_  =
     (T_VisagePattern (let _lhsOaterm :: ATerm
                           -- "Visage.ag"(line 117, column 18)
                           _lhsOaterm =
-                              AAppl "Pattern" [AAppl "Var" [AString (sQ (showAGPos (getPos field_))),
-                                                            AString (sQ (getName field_ ++ "." ++ getName attr_))]]
+                              ({-# LINE 117 "Visage.ag" #-}
+                               AAppl "Pattern" [AAppl "Var" [AString (sQ (showAGPos (getPos field_))),
+                                                             AString (sQ (getName field_ ++ "." ++ getName attr_))]]
+                               {-# LINE 466 "Visage.hs" #-}
+                               )
                       in  ( _lhsOaterm)) )
 -- VisagePatterns ----------------------------------------------
 {-
@@ -439,13 +484,12 @@ sem_VisagePatterns list  =
 -- semantic domain
 newtype T_VisagePatterns  = T_VisagePatterns (( ([ATerm])))
 data Inh_VisagePatterns  = Inh_VisagePatterns {}
-data Syn_VisagePatterns  = Syn_VisagePatterns {aterms_Syn_VisagePatterns :: [ATerm]}
+data Syn_VisagePatterns  = Syn_VisagePatterns {aterms_Syn_VisagePatterns :: ([ATerm])}
 wrap_VisagePatterns :: T_VisagePatterns  ->
                        Inh_VisagePatterns  ->
                        Syn_VisagePatterns 
 wrap_VisagePatterns (T_VisagePatterns sem ) (Inh_VisagePatterns )  =
-    (let ( _lhsOaterms) =
-             (sem )
+    (let ( _lhsOaterms) = sem 
      in  (Syn_VisagePatterns _lhsOaterms ))
 sem_VisagePatterns_Cons :: T_VisagePattern  ->
                            T_VisagePatterns  ->
@@ -456,18 +500,24 @@ sem_VisagePatterns_Cons (T_VisagePattern hd_ ) (T_VisagePatterns tl_ )  =
                            _tlIaterms :: ([ATerm])
                            -- "Visage.ag"(line 107, column 17)
                            _lhsOaterms =
-                               _hdIaterm : _tlIaterms
+                               ({-# LINE 107 "Visage.ag" #-}
+                                _hdIaterm : _tlIaterms
+                                {-# LINE 506 "Visage.hs" #-}
+                                )
                            ( _hdIaterm) =
-                               (hd_ )
+                               hd_ 
                            ( _tlIaterms) =
-                               (tl_ )
+                               tl_ 
                        in  ( _lhsOaterms)) )
 sem_VisagePatterns_Nil :: T_VisagePatterns 
 sem_VisagePatterns_Nil  =
     (T_VisagePatterns (let _lhsOaterms :: ([ATerm])
                            -- "Visage.ag"(line 108, column 17)
                            _lhsOaterms =
-                               []
+                               ({-# LINE 108 "Visage.ag" #-}
+                                []
+                                {-# LINE 520 "Visage.hs" #-}
+                                )
                        in  ( _lhsOaterms)) )
 -- VisageProduction --------------------------------------------
 {-
@@ -494,8 +544,7 @@ wrap_VisageProduction :: T_VisageProduction  ->
                          Inh_VisageProduction  ->
                          Syn_VisageProduction 
 wrap_VisageProduction (T_VisageProduction sem ) (Inh_VisageProduction )  =
-    (let ( _lhsOaterm) =
-             (sem )
+    (let ( _lhsOaterm) = sem 
      in  (Syn_VisageProduction _lhsOaterm ))
 sem_VisageProduction_VProduction :: ConstructorIdent ->
                                     T_VisageChildren  ->
@@ -511,21 +560,30 @@ sem_VisageProduction_VProduction con_ (T_VisageChildren children_ ) (T_VisageRul
                              _locrulesIaterms :: ([ATerm])
                              -- "Visage.ag"(line 73, column 17)
                              _lhsOaterm =
-                                 AAppl "Alternative" [AString (sQ (getName con_)), AAppl "Children" _childrenIaterms,
-                                                       AAppl "Rules" _rulesIaterms,
-                                                       AAppl "LocRules" _locrulesIaterms]
+                                 ({-# LINE 73 "Visage.ag" #-}
+                                  AAppl "Alternative" [AString (sQ (getName con_)), AAppl "Children" _childrenIaterms,
+                                                        AAppl "Rules" _rulesIaterms,
+                                                        AAppl "LocRules" _locrulesIaterms]
+                                  {-# LINE 568 "Visage.hs" #-}
+                                  )
                              -- "Visage.ag"(line 76, column 18)
                              _locrulesOisLoc =
-                                 True
+                                 ({-# LINE 76 "Visage.ag" #-}
+                                  True
+                                  {-# LINE 574 "Visage.hs" #-}
+                                  )
                              -- "Visage.ag"(line 77, column 18)
                              _rulesOisLoc =
-                                 False
+                                 ({-# LINE 77 "Visage.ag" #-}
+                                  False
+                                  {-# LINE 580 "Visage.hs" #-}
+                                  )
                              ( _childrenIaterms) =
-                                 (children_ )
+                                 children_ 
                              ( _rulesIaterms) =
-                                 (rules_ _rulesOisLoc )
+                                 rules_ _rulesOisLoc 
                              ( _locrulesIaterms) =
-                                 (locrules_ _locrulesOisLoc )
+                                 locrules_ _locrulesOisLoc 
                          in  ( _lhsOaterm)) )
 -- VisageProductions -------------------------------------------
 {-
@@ -546,13 +604,12 @@ sem_VisageProductions list  =
 -- semantic domain
 newtype T_VisageProductions  = T_VisageProductions (( ([ATerm])))
 data Inh_VisageProductions  = Inh_VisageProductions {}
-data Syn_VisageProductions  = Syn_VisageProductions {aterms_Syn_VisageProductions :: [ATerm]}
+data Syn_VisageProductions  = Syn_VisageProductions {aterms_Syn_VisageProductions :: ([ATerm])}
 wrap_VisageProductions :: T_VisageProductions  ->
                           Inh_VisageProductions  ->
                           Syn_VisageProductions 
 wrap_VisageProductions (T_VisageProductions sem ) (Inh_VisageProductions )  =
-    (let ( _lhsOaterms) =
-             (sem )
+    (let ( _lhsOaterms) = sem 
      in  (Syn_VisageProductions _lhsOaterms ))
 sem_VisageProductions_Cons :: T_VisageProduction  ->
                               T_VisageProductions  ->
@@ -563,18 +620,24 @@ sem_VisageProductions_Cons (T_VisageProduction hd_ ) (T_VisageProductions tl_ )
                               _tlIaterms :: ([ATerm])
                               -- "Visage.ag"(line 68, column 17)
                               _lhsOaterms =
-                                  _hdIaterm : _tlIaterms
+                                  ({-# LINE 68 "Visage.ag" #-}
+                                   _hdIaterm : _tlIaterms
+                                   {-# LINE 626 "Visage.hs" #-}
+                                   )
                               ( _hdIaterm) =
-                                  (hd_ )
+                                  hd_ 
                               ( _tlIaterms) =
-                                  (tl_ )
+                                  tl_ 
                           in  ( _lhsOaterms)) )
 sem_VisageProductions_Nil :: T_VisageProductions 
 sem_VisageProductions_Nil  =
     (T_VisageProductions (let _lhsOaterms :: ([ATerm])
                               -- "Visage.ag"(line 69, column 17)
                               _lhsOaterms =
-                                  []
+                                  ({-# LINE 69 "Visage.ag" #-}
+                                   []
+                                   {-# LINE 640 "Visage.hs" #-}
+                                   )
                           in  ( _lhsOaterms)) )
 -- VisageRule --------------------------------------------------
 {-
@@ -605,8 +668,7 @@ wrap_VisageRule :: T_VisageRule  ->
                    Inh_VisageRule  ->
                    Syn_VisageRule 
 wrap_VisageRule (T_VisageRule sem ) (Inh_VisageRule _lhsIisLoc )  =
-    (let ( _lhsOaterm) =
-             (sem _lhsIisLoc )
+    (let ( _lhsOaterm) = sem _lhsIisLoc 
      in  (Syn_VisageRule _lhsOaterm ))
 sem_VisageRule_VRule :: ([(Identifier,Identifier)]) ->
                         Identifier ->
@@ -621,12 +683,15 @@ sem_VisageRule_VRule fieldattrs_ attr_ (T_VisagePattern pat_ ) (T_Expression rhs
                             _rhsIaterm :: ATerm
                             -- "Visage.ag"(line 97, column 18)
                             _lhsOaterm =
-                                AAppl (if _lhsIisLoc then "LocRule" else "Rule")
-                                      ([AString (sQ (getName attr_)), _patIaterm, _rhsIaterm] ++ if _lhsIisLoc then [AString (sQ (show owrt_))] else [])
+                                ({-# LINE 97 "Visage.ag" #-}
+                                 AAppl (if _lhsIisLoc then "LocRule" else "Rule")
+                                       ([AString (sQ (getName attr_)), _patIaterm, _rhsIaterm] ++ if _lhsIisLoc then [AString (sQ (show owrt_))] else [])
+                                 {-# LINE 690 "Visage.hs" #-}
+                                 )
                             ( _patIaterm) =
-                                (pat_ )
+                                pat_ 
                             ( _rhsIaterm) =
-                                (rhs_ )
+                                rhs_ 
                         in  ( _lhsOaterm))) )
 -- VisageRules -------------------------------------------------
 {-
@@ -650,13 +715,12 @@ sem_VisageRules list  =
 newtype T_VisageRules  = T_VisageRules (Bool ->
                                         ( ([ATerm])))
 data Inh_VisageRules  = Inh_VisageRules {isLoc_Inh_VisageRules :: Bool}
-data Syn_VisageRules  = Syn_VisageRules {aterms_Syn_VisageRules :: [ATerm]}
+data Syn_VisageRules  = Syn_VisageRules {aterms_Syn_VisageRules :: ([ATerm])}
 wrap_VisageRules :: T_VisageRules  ->
                     Inh_VisageRules  ->
                     Syn_VisageRules 
 wrap_VisageRules (T_VisageRules sem ) (Inh_VisageRules _lhsIisLoc )  =
-    (let ( _lhsOaterms) =
-             (sem _lhsIisLoc )
+    (let ( _lhsOaterms) = sem _lhsIisLoc 
      in  (Syn_VisageRules _lhsOaterms ))
 sem_VisageRules_Cons :: T_VisageRule  ->
                         T_VisageRules  ->
@@ -670,17 +734,26 @@ sem_VisageRules_Cons (T_VisageRule hd_ ) (T_VisageRules tl_ )  =
                              _tlIaterms :: ([ATerm])
                              -- "Visage.ag"(line 92, column 17)
                              _lhsOaterms =
-                                 _hdIaterm : _tlIaterms
+                                 ({-# LINE 92 "Visage.ag" #-}
+                                  _hdIaterm : _tlIaterms
+                                  {-# LINE 740 "Visage.hs" #-}
+                                  )
                              -- copy rule (down)
                              _hdOisLoc =
-                                 _lhsIisLoc
+                                 ({-# LINE 51 "Visage.ag" #-}
+                                  _lhsIisLoc
+                                  {-# LINE 746 "Visage.hs" #-}
+                                  )
                              -- copy rule (down)
                              _tlOisLoc =
-                                 _lhsIisLoc
+                                 ({-# LINE 51 "Visage.ag" #-}
+                                  _lhsIisLoc
+                                  {-# LINE 752 "Visage.hs" #-}
+                                  )
                              ( _hdIaterm) =
-                                 (hd_ _hdOisLoc )
+                                 hd_ _hdOisLoc 
                              ( _tlIaterms) =
-                                 (tl_ _tlOisLoc )
+                                 tl_ _tlOisLoc 
                          in  ( _lhsOaterms))) )
 sem_VisageRules_Nil :: T_VisageRules 
 sem_VisageRules_Nil  =
@@ -688,5 +761,8 @@ sem_VisageRules_Nil  =
                         (let _lhsOaterms :: ([ATerm])
                              -- "Visage.ag"(line 93, column 17)
                              _lhsOaterms =
-                                 []
+                                 ({-# LINE 93 "Visage.ag" #-}
+                                  []
+                                  {-# LINE 767 "Visage.hs" #-}
+                                  )
                          in  ( _lhsOaterms))) )
\ No newline at end of file
