@@ -1,10 +1,12 @@
 
 
--- UUAGC 0.9.14 (VisagePatterns.ag)
+-- UUAGC 0.9.37.1 (VisagePatterns.ag)
 module VisagePatterns where
+{-# LINE 2 "VisagePatterns.ag" #-}
 
 import UU.Scanner.Position(Pos)
 import CommonTypes
+{-# LINE 10 "../src-derived/VisagePatterns.hs" #-}
 -- VisagePattern -----------------------------------------------
 {-
    alternatives:
@@ -24,9 +26,9 @@ import CommonTypes
          child field          : {Identifier}
          child attr           : {Identifier}
 -}
-data VisagePattern  = VAlias (Identifier) (Identifier) (VisagePattern) 
-                    | VConstr (ConstructorIdent) (VisagePatterns) 
-                    | VProduct (Pos) (VisagePatterns) 
+data VisagePattern  = VAlias (Identifier) (Identifier) (VisagePattern ) 
+                    | VConstr (ConstructorIdent) (VisagePatterns ) 
+                    | VProduct (Pos) (VisagePatterns ) 
                     | VUnderscore (Pos) 
                     | VVar (Identifier) (Identifier) 
 -- VisagePatterns ----------------------------------------------
@@ -37,4 +39,4 @@ data VisagePattern  = VAlias (Identifier) (Identifier) (VisagePattern)
          child tl             : VisagePatterns 
       alternative Nil:
 -}
-type VisagePatterns  = [(VisagePattern)]
\ No newline at end of file
+type VisagePatterns  = [VisagePattern ]
\ No newline at end of file
