@@ -1,13 +1,15 @@
 
 
--- UUAGC 0.9.14 (VisageSyntax.ag)
+-- UUAGC 0.9.37.1 (VisageSyntax.ag)
 module VisageSyntax where
+{-# LINE 2 "VisageSyntax.ag" #-}
 
 import CommonTypes
 import UU.Pretty
 import AbstractSyntax
 import VisagePatterns
 import Expression
+{-# LINE 13 "../src-derived/VisageSyntax.hs" #-}
 -- VisageChild -------------------------------------------------
 {-
    alternatives:
@@ -18,7 +20,7 @@ import Expression
          child syn            : {Attributes}
          child rules          : VisageRules 
 -}
-data VisageChild  = VChild (Identifier) (Type) (Attributes) (Attributes) (VisageRules) 
+data VisageChild  = VChild (Identifier) (Type) (Attributes) (Attributes) (VisageRules ) 
 -- VisageChildren ----------------------------------------------
 {-
    alternatives:
@@ -27,14 +29,14 @@ data VisageChild  = VChild (Identifier) (Type) (Attributes) (Attributes) (Visage
          child tl             : VisageChildren 
       alternative Nil:
 -}
-type VisageChildren  = [(VisageChild)]
+type VisageChildren  = [VisageChild ]
 -- VisageGrammar -----------------------------------------------
 {-
    alternatives:
       alternative VGrammar:
          child nonts          : VisageNonterminals 
 -}
-data VisageGrammar  = VGrammar (VisageNonterminals) 
+data VisageGrammar  = VGrammar (VisageNonterminals ) 
 -- VisageNonterminal -------------------------------------------
 {-
    alternatives:
@@ -44,7 +46,7 @@ data VisageGrammar  = VGrammar (VisageNonterminals)
          child syn            : {Attributes}
          child alts           : VisageProductions 
 -}
-data VisageNonterminal  = VNonterminal (NontermIdent) (Attributes) (Attributes) (VisageProductions) 
+data VisageNonterminal  = VNonterminal (NontermIdent) (Attributes) (Attributes) (VisageProductions ) 
 -- VisageNonterminals ------------------------------------------
 {-
    alternatives:
@@ -53,7 +55,7 @@ data VisageNonterminal  = VNonterminal (NontermIdent) (Attributes) (Attributes)
          child tl             : VisageNonterminals 
       alternative Nil:
 -}
-type VisageNonterminals  = [(VisageNonterminal)]
+type VisageNonterminals  = [VisageNonterminal ]
 -- VisageProduction --------------------------------------------
 {-
    alternatives:
@@ -63,7 +65,7 @@ type VisageNonterminals  = [(VisageNonterminal)]
          child rules          : VisageRules 
          child locrules       : VisageRules 
 -}
-data VisageProduction  = VProduction (ConstructorIdent) (VisageChildren) (VisageRules) (VisageRules) 
+data VisageProduction  = VProduction (ConstructorIdent) (VisageChildren ) (VisageRules ) (VisageRules ) 
 -- VisageProductions -------------------------------------------
 {-
    alternatives:
@@ -72,7 +74,7 @@ data VisageProduction  = VProduction (ConstructorIdent) (VisageChildren) (Visage
          child tl             : VisageProductions 
       alternative Nil:
 -}
-type VisageProductions  = [(VisageProduction)]
+type VisageProductions  = [VisageProduction ]
 -- VisageRule --------------------------------------------------
 {-
    alternatives:
@@ -83,7 +85,7 @@ type VisageProductions  = [(VisageProduction)]
          child rhs            : {Expression}
          child owrt           : {Bool}
 -}
-data VisageRule  = VRule ([(Identifier,Identifier)]) (Identifier) (VisagePattern) (Expression) (Bool) 
+data VisageRule  = VRule (([(Identifier,Identifier)])) (Identifier) (VisagePattern) (Expression) (Bool) 
 -- VisageRules -------------------------------------------------
 {-
    alternatives:
@@ -92,4 +94,4 @@ data VisageRule  = VRule ([(Identifier,Identifier)]) (Identifier) (VisagePattern
          child tl             : VisageRules 
       alternative Nil:
 -}
-type VisageRules  = [(VisageRule)]
\ No newline at end of file
+type VisageRules  = [VisageRule ]
\ No newline at end of file
