@@ -1,6 +1,9 @@
 module Options where
 
 import System.Console.GetOpt
+import CommonTypes
+import Data.Set(Set)
+import qualified Data.Set as Set
 
 options     :: [OptDescr (Options -> Options)]
 options     =  [ Option ['m']     []                (NoArg (moduleOpt Nothing)) "generate default module header"
@@ -50,12 +53,24 @@ options     =  [ Option ['m']     []                (NoArg (moduleOpt Nothing))
                , Option []        ["sepsemmods"]    (NoArg sepSemModsOpt)       "Generate separate modules for semantic functions (in generated code)"
                , Option ['M']     ["genfiledeps"] (NoArg genFileDepsOpt) "Generate a list of dependencies on the input AG files"
                , Option []        ["genvisage"] (NoArg genVisageOpt)  "Generate output for the AG visualizer Visage"
+               , Option []        ["genAspectAG"] (NoArg genAspectAGOpt)  "Generate AspectAG file"
                , Option []        ["genattrlist"] (NoArg genAttrListOpt) "Generate a list of all explicitly defined attributes (outside irrefutable patterns)"
                , Option []        ["forceirrefutable"] (OptArg forceIrrefutableOpt "file") "Force a set of explicitly defined attributes to be irrefutable, specify file containing the attribute set"
                , Option []        ["uniquedispenser"] (ReqArg uniqueDispenserOpt "name") "The Haskell function to call in the generated code"
                , Option []        ["lckeywords"]      (NoArg lcKeywordsOpt) "Use lowercase keywords (sem, attr) instead of the uppercase ones (SEM, ATTR)"
                , Option []        ["doublecolons"]    (NoArg doubleColonsOpt) "Use double colons for type signatures instead of single colons"
                , Option ['H']     ["haskellsyntax"]   (NoArg haskellSyntaxOpt) "Use Haskell like syntax (equivalent to --lckeywords and --doublecolons --genlinepragmas)"
+               , Option []        ["monadic"]         (NoArg monadicOpt) "Experimental: generate monadic code"
+               , Option []        ["ocaml"]           (NoArg ocamlOpt) "Experimental: generate Ocaml code"
+               , Option []        ["breadthfirst"]      (NoArg breadthfirstOpt) "Experimental: generate breadth-first code"
+               , Option []        ["breadthfirst-strict"] (NoArg breadthfirstStrictOpt) "Experimental: outermost breadth-first evaluator is strict instead of lazy"
+               , Option []        ["visitcode"]        (NoArg visitorsOutputOpt) "Experimental: generate visitors code"
+               , Option []        ["statistics"]      (ReqArg statisticsOpt "FILE to append to") "Append statistics to FILE"
+               , Option []        ["checkParseRhs"]         (NoArg parseHsRhsOpt) "Parse RHS of rules with Haskell parser"
+               , Option []        ["checkParseTys"]         (NoArg parseHsTpOpt) "Parse types of attrs with Haskell parser"
+               , Option []        ["checkParseBlocks"]         (NoArg parseHsBlockOpt) "Parse blocks with Haskell parser"
+               , Option []        ["checkParseHaskell"]  (NoArg parseHsOpt) "Parse Haskell code (recognizer)"
+               , Option []        ["nocatas"]           (ReqArg nocatasOpt "list of nonterms") "Nonterminals not to generate catas for"
                ]
 
 allc = "dcfsprm"
@@ -104,11 +119,22 @@ data Options = Options{ moduleName :: ModuleHeader
                       , genFileDeps :: Bool
                       , genLinePragmas :: Bool
                       , genvisage :: Bool
+                      , genAspectAG :: Bool
                       , genAttributeList :: Bool
                       , forceIrrefutables :: Maybe String
                       , uniqueDispenser :: String
                       , lcKeywords :: Bool
                       , doubleColons :: Bool
+                      , monadic :: Bool
+                      , ocaml :: Bool
+                      , visitorsOutput :: Bool
+                      , statsFile :: Maybe String
+                      , breadthFirst :: Bool
+                      , breadthFirstStrict :: Bool
+                      , checkParseRhs :: Bool
+                      , checkParseTy :: Bool
+                      , checkParseBlock :: Bool
+                      , nocatas :: Set NontermIdent
                       } deriving Show
 noOptions = Options { moduleName    = NoName
                     , dataTypes     = False
@@ -154,14 +180,24 @@ noOptions = Options { moduleName    = NoName
                     , genFileDeps    = False
                     , genLinePragmas = False
                     , genvisage      = False
+                    , genAspectAG    = False
                     , genAttributeList = False
                     , forceIrrefutables = Nothing
                     , uniqueDispenser = "nextUnique"
                     , lcKeywords      = False
                     , doubleColons    = False
+                    , monadic         = False
+                    , ocaml           = False
+                    , visitorsOutput  = False
+                    , statsFile       = Nothing
+                    , breadthFirst     = False
+                    , breadthFirstStrict = False
+                    , checkParseRhs = False
+                    , checkParseTy  = False
+                    , checkParseBlock = False
+                    , nocatas         = Set.empty
                     }
 
-
 moduleOpt  nm   opts = opts{moduleName   = maybe Default Name nm}            
 dataOpt         opts = opts{dataTypes    = True}            
 strictDataOpt   opts = opts{strictData   = True}            
@@ -204,12 +240,31 @@ sepSemModsOpt opts = opts{sepSemMods = True}
 genFileDepsOpt opts = opts{genFileDeps = True}
 genLinePragmasOpt opts = opts{genLinePragmas = True}
 genVisageOpt opts = opts{genvisage = True }
+genAspectAGOpt opts = opts{genAspectAG = True}
 genAttrListOpt opts = opts { genAttributeList = True }
 forceIrrefutableOpt mbNm opts = opts { forceIrrefutables = mbNm }
 uniqueDispenserOpt nm opts = opts { uniqueDispenser = nm }
 lcKeywordsOpt opts = opts { lcKeywords = True }
 doubleColonsOpt opts = opts { doubleColons = True }
 haskellSyntaxOpt = lcKeywordsOpt . doubleColonsOpt . genLinePragmasOpt
+monadicOpt opts = opts { monadic = True }
+ocamlOpt opts = opts { ocaml = True }
+visitorsOutputOpt opts = opts { visitorsOutput = True }
+statisticsOpt nm opts = opts { statsFile = Just nm }
+breadthfirstOpt opts = opts { breadthFirst = True }
+breadthfirstStrictOpt opts = opts { breadthFirstStrict = True }
+parseHsRhsOpt opts = opts { checkParseRhs = True }
+parseHsTpOpt opts = opts { checkParseTy = True }
+parseHsBlockOpt opts = opts { checkParseBlock = True }
+parseHsOpt = parseHsRhsOpt . parseHsTpOpt . parseHsBlockOpt
+nocatasOpt str opts = opts { nocatas = set `Set.union` nocatas opts } where
+  set = Set.fromList ids
+  ids = map identifier lst
+  lst = split str
+
+  split str | null p   = []
+            | otherwise = p : split ps
+    where (p,ps) = break (== ',') str
 
 outputOpt  file  opts = opts{outputFiles  = file : outputFiles opts}            
 searchPathOpt  path  opts = opts{searchPath  = extract path ++ searchPath opts}            
@@ -224,4 +279,3 @@ getOptions args = let (flags,files,errors) = getOpt Permute options args
 data ModuleHeader  = NoName
                    | Name String
                    | Default deriving Show
-
