@@ -1,5 +1,5 @@
-{-# OPTIONS -fglasgow-exts #-}
-
+{-# LANGUAGE MagicHash,
+             UnboxedTuples #-}
 module Scanner where
 import GHC.Prim
 import TokenDef
@@ -50,7 +50,8 @@ scan opts
   
     scan :: Lexer Token
     scan p []                        = Nothing
-    scan p ('-':'-':xs)              = let (com,rest) = span (/= '\n') xs
+    scan p ('-':'-':xs) | null xs || not (head xs `elem` "<>!?#@:%$^&")    
+                                     = let (com,rest) = span (/= '\n') xs
                                        in advc' (2+length com) p scan rest
     scan p ('{':'-':xs)              = advc' 2 p (ncomment scan) xs
     scan p ('{'    :xs)              = advc' 1 p codescrap xs
@@ -131,9 +132,9 @@ ident = span isValid
 lowercaseKeywords = ["loc","lhs", "inst"]
 keywords = lowercaseKeywords ++
            [ "DATA", "EXT", "ATTR", "SEM","TYPE", "USE", "INCLUDE"
-           , "SET","DERIVING","FOR", "WRAPPER", "MAYBE", "EITHER", "MAP", "INTMAP"
-           , "PRAGMA", "SEMPRAGMA", "MODULE", "ATTACH", "UNIQUEREF", "INH", "SYN"
-           , "AUGMENT"
+           , "SET","DERIVING","FOR", "WRAPPER", "NOCATAS", "MAYBE", "EITHER", "MAP", "INTMAP"
+           , "PRAGMA", "SEMPRAGMA", "MODULE", "ATTACH", "UNIQUEREF", "INH", "SYN", "CHN"
+           , "AUGMENT", "AROUND", "MERGE", "AS"
            ]
 
 ncomment c p ('-':'}':xs) = advc' 2 p c  xs
